Class: OpenApiOpenAIClient::BatchApi
- Inherits:
-
Object
- Object
- OpenApiOpenAIClient::BatchApi
- Defined in:
- lib/openapi_openai/api/batch_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel_batch(batch_id, opts = {}) ⇒ Batch
Cancels an in-progress batch.
-
#cancel_batch_with_http_info(batch_id, opts = {}) ⇒ Array<(Batch, Integer, Hash)>
Cancels an in-progress batch.
-
#create_batch(create_batch_request, opts = {}) ⇒ Batch
Creates and executes a batch from an uploaded file of requests.
-
#create_batch_with_http_info(create_batch_request, opts = {}) ⇒ Array<(Batch, Integer, Hash)>
Creates and executes a batch from an uploaded file of requests.
-
#initialize(api_client = ApiClient.default) ⇒ BatchApi
constructor
A new instance of BatchApi.
-
#list_batches(opts = {}) ⇒ ListBatchesResponse
List your organization’s batches.
-
#list_batches_with_http_info(opts = {}) ⇒ Array<(ListBatchesResponse, Integer, Hash)>
List your organization's batches.
-
#retrieve_batch(batch_id, opts = {}) ⇒ Batch
Retrieves a batch.
-
#retrieve_batch_with_http_info(batch_id, opts = {}) ⇒ Array<(Batch, Integer, Hash)>
Retrieves a batch.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BatchApi
Returns a new instance of BatchApi.
19 20 21 |
# File 'lib/openapi_openai/api/batch_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/openapi_openai/api/batch_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cancel_batch(batch_id, opts = {}) ⇒ Batch
Cancels an in-progress batch. The batch will be in status cancelling for up to 10 minutes, before changing to cancelled, where it will have partial results (if any) available in the output file.
26 27 28 29 |
# File 'lib/openapi_openai/api/batch_api.rb', line 26 def cancel_batch(batch_id, opts = {}) data, _status_code, _headers = cancel_batch_with_http_info(batch_id, opts) data end |
#cancel_batch_with_http_info(batch_id, opts = {}) ⇒ Array<(Batch, Integer, Hash)>
Cancels an in-progress batch. The batch will be in status `cancelling` for up to 10 minutes, before changing to `cancelled`, where it will have partial results (if any) available in the output file.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/openapi_openai/api/batch_api.rb', line 35 def cancel_batch_with_http_info(batch_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BatchApi.cancel_batch ...' end # verify the required parameter 'batch_id' is set if @api_client.config.client_side_validation && batch_id.nil? fail ArgumentError, "Missing the required parameter 'batch_id' when calling BatchApi.cancel_batch" end # resource path local_var_path = '/batches/{batch_id}/cancel'.sub('{' + 'batch_id' + '}', CGI.escape(batch_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Batch' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BatchApi.cancel_batch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BatchApi#cancel_batch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_batch(create_batch_request, opts = {}) ⇒ Batch
Creates and executes a batch from an uploaded file of requests
87 88 89 90 |
# File 'lib/openapi_openai/api/batch_api.rb', line 87 def create_batch(create_batch_request, opts = {}) data, _status_code, _headers = create_batch_with_http_info(create_batch_request, opts) data end |
#create_batch_with_http_info(create_batch_request, opts = {}) ⇒ Array<(Batch, Integer, Hash)>
Creates and executes a batch from an uploaded file of requests
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/openapi_openai/api/batch_api.rb', line 96 def create_batch_with_http_info(create_batch_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BatchApi.create_batch ...' end # verify the required parameter 'create_batch_request' is set if @api_client.config.client_side_validation && create_batch_request.nil? fail ArgumentError, "Missing the required parameter 'create_batch_request' when calling BatchApi.create_batch" end # resource path local_var_path = '/batches' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_batch_request) # return_type return_type = opts[:debug_return_type] || 'Batch' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BatchApi.create_batch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BatchApi#create_batch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_batches(opts = {}) ⇒ ListBatchesResponse
List your organization’s batches.
154 155 156 157 |
# File 'lib/openapi_openai/api/batch_api.rb', line 154 def list_batches(opts = {}) data, _status_code, _headers = list_batches_with_http_info(opts) data end |
#list_batches_with_http_info(opts = {}) ⇒ Array<(ListBatchesResponse, Integer, Hash)>
List your organization's batches.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/openapi_openai/api/batch_api.rb', line 164 def list_batches_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BatchApi.list_batches ...' end # resource path local_var_path = '/batches' # query parameters query_params = opts[:query_params] || {} query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListBatchesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BatchApi.list_batches", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BatchApi#list_batches\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retrieve_batch(batch_id, opts = {}) ⇒ Batch
Retrieves a batch.
214 215 216 217 |
# File 'lib/openapi_openai/api/batch_api.rb', line 214 def retrieve_batch(batch_id, opts = {}) data, _status_code, _headers = retrieve_batch_with_http_info(batch_id, opts) data end |
#retrieve_batch_with_http_info(batch_id, opts = {}) ⇒ Array<(Batch, Integer, Hash)>
Retrieves a batch.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/openapi_openai/api/batch_api.rb', line 223 def retrieve_batch_with_http_info(batch_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BatchApi.retrieve_batch ...' end # verify the required parameter 'batch_id' is set if @api_client.config.client_side_validation && batch_id.nil? fail ArgumentError, "Missing the required parameter 'batch_id' when calling BatchApi.retrieve_batch" end # resource path local_var_path = '/batches/{batch_id}'.sub('{' + 'batch_id' + '}', CGI.escape(batch_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Batch' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BatchApi.retrieve_batch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BatchApi#retrieve_batch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |