Class: OpenApiOpenAIClient::ChatApi

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_openai/api/chat_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ChatApi

Returns a new instance of ChatApi.



19
20
21
# File 'lib/openapi_openai/api/chat_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/openapi_openai/api/chat_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_chat_completion(create_chat_completion_request, opts = {}) ⇒ CreateChatCompletionResponse

Creates a model response for the given chat conversation. Learn more in the [text generation](/docs/guides/text-generation), [vision](/docs/guides/vision), and [audio](/docs/guides/audio) guides. Parameter support can differ depending on the model used to generate the response, particularly for newer reasoning models. Parameters that are only supported for reasoning models are noted below. For the current state of unsupported parameters in reasoning models, [refer to the reasoning guide](/docs/guides/reasoning).

Parameters:

Returns:



26
27
28
29
# File 'lib/openapi_openai/api/chat_api.rb', line 26

def create_chat_completion(create_chat_completion_request, opts = {})
  data, _status_code, _headers = create_chat_completion_with_http_info(create_chat_completion_request, opts)
  data
end

#create_chat_completion_with_http_info(create_chat_completion_request, opts = {}) ⇒ Array<(CreateChatCompletionResponse, Integer, Hash)>

Creates a model response for the given chat conversation. Learn more in the [text generation](/docs/guides/text-generation), [vision](/docs/guides/vision), and [audio](/docs/guides/audio) guides. Parameter support can differ depending on the model used to generate the response, particularly for newer reasoning models. Parameters that are only supported for reasoning models are noted below. For the current state of unsupported parameters in reasoning models, [refer to the reasoning guide](/docs/guides/reasoning).

Parameters:

Returns:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/openapi_openai/api/chat_api.rb', line 35

def create_chat_completion_with_http_info(create_chat_completion_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ChatApi.create_chat_completion ...'
  end
  # verify the required parameter 'create_chat_completion_request' is set
  if @api_client.config.client_side_validation && create_chat_completion_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_chat_completion_request' when calling ChatApi.create_chat_completion"
  end
  # resource path
  local_var_path = '/chat/completions'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_chat_completion_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateChatCompletionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"ChatApi.create_chat_completion",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChatApi#create_chat_completion\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end