Class: OpenApiOpenAIClient::CostsResult

Inherits:
ApiModelBase show all
Defined in:
lib/openapi_openai/models/costs_result.rb

Overview

The aggregated costs details of the specific time bucket.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CostsResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/openapi_openai/models/costs_result.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenApiOpenAIClient::CostsResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenApiOpenAIClient::CostsResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'line_item')
    self.line_item = attributes[:'line_item']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



21
22
23
# File 'lib/openapi_openai/models/costs_result.rb', line 21

def amount
  @amount
end

#line_itemObject

When ‘group_by=line_item`, this field provides the line item of the grouped costs result.



24
25
26
# File 'lib/openapi_openai/models/costs_result.rb', line 24

def line_item
  @line_item
end

#objectObject

Returns the value of attribute object.



19
20
21
# File 'lib/openapi_openai/models/costs_result.rb', line 19

def object
  @object
end

#project_idObject

When ‘group_by=project_id`, this field provides the project ID of the grouped costs result.



27
28
29
# File 'lib/openapi_openai/models/costs_result.rb', line 27

def project_id
  @project_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/openapi_openai/models/costs_result.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/openapi_openai/models/costs_result.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
# File 'lib/openapi_openai/models/costs_result.rb', line 52

def self.attribute_map
  {
    :'object' => :'object',
    :'amount' => :'amount',
    :'line_item' => :'line_item',
    :'project_id' => :'project_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/openapi_openai/models/costs_result.rb', line 182

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
# File 'lib/openapi_openai/models/costs_result.rb', line 82

def self.openapi_nullable
  Set.new([
    :'line_item',
    :'project_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
# File 'lib/openapi_openai/models/costs_result.rb', line 72

def self.openapi_types
  {
    :'object' => :'String',
    :'amount' => :'CostsResultAmount',
    :'line_item' => :'String',
    :'project_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



158
159
160
161
162
163
164
165
# File 'lib/openapi_openai/models/costs_result.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      object == o.object &&
      amount == o.amount &&
      line_item == o.line_item &&
      project_id == o.project_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


169
170
171
# File 'lib/openapi_openai/models/costs_result.rb', line 169

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



175
176
177
# File 'lib/openapi_openai/models/costs_result.rb', line 175

def hash
  [object, amount, line_item, project_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
# File 'lib/openapi_openai/models/costs_result.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/openapi_openai/models/costs_result.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
142
143
144
# File 'lib/openapi_openai/models/costs_result.rb', line 138

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["organization.costs.result"])
  return false unless object_validator.valid?(@object)
  true
end