Class: OpenApiOpenAIClient::CreateTranscriptionResponseVerboseJson

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/openapi_openai/models/create_transcription_response_verbose_json.rb

Overview

Represents a verbose json transcription response returned by model, based on the provided input.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateTranscriptionResponseVerboseJson

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenApiOpenAIClient::CreateTranscriptionResponseVerboseJson` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenApiOpenAIClient::CreateTranscriptionResponseVerboseJson`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  else
    self.language = nil
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  else
    self.duration = nil
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'words')
    if (value = attributes[:'words']).is_a?(Array)
      self.words = value
    end
  end

  if attributes.key?(:'segments')
    if (value = attributes[:'segments']).is_a?(Array)
      self.segments = value
    end
  end
end

Instance Attribute Details

#durationObject

The duration of the input audio.



23
24
25
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 23

def duration
  @duration
end

#languageObject

The language of the input audio.



20
21
22
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 20

def language
  @language
end

#segmentsObject

Segments of the transcribed text and their corresponding details.



32
33
34
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 32

def segments
  @segments
end

#textObject

The transcribed text.



26
27
28
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 26

def text
  @text
end

#wordsObject

Extracted words and their corresponding timestamps.



29
30
31
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 29

def words
  @words
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 35

def self.attribute_map
  {
    :'language' => :'language',
    :'duration' => :'duration',
    :'text' => :'text',
    :'words' => :'words',
    :'segments' => :'segments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 206

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 56

def self.openapi_types
  {
    :'language' => :'String',
    :'duration' => :'String',
    :'text' => :'String',
    :'words' => :'Array<TranscriptionWord>',
    :'segments' => :'Array<TranscriptionSegment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      language == o.language &&
      duration == o.duration &&
      text == o.text &&
      words == o.words &&
      segments == o.segments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


193
194
195
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 193

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



199
200
201
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 199

def hash
  [language, duration, text, words, segments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @language.nil?
    invalid_properties.push('invalid value for "language", language cannot be nil.')
  end

  if @duration.nil?
    invalid_properties.push('invalid value for "duration", duration cannot be nil.')
  end

  if @text.nil?
    invalid_properties.push('invalid value for "text", text cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
# File 'lib/openapi_openai/models/create_transcription_response_verbose_json.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @language.nil?
  return false if @duration.nil?
  return false if @text.nil?
  true
end