Class: OpenApiOpenAIClient::FineTuneDPOMethodHyperparameters
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenApiOpenAIClient::FineTuneDPOMethodHyperparameters
- Defined in:
- lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb
Overview
The hyperparameters used for the fine-tuning job.
Instance Attribute Summary collapse
-
#batch_size ⇒ Object
Returns the value of attribute batch_size.
-
#beta ⇒ Object
Returns the value of attribute beta.
-
#learning_rate_multiplier ⇒ Object
Returns the value of attribute learning_rate_multiplier.
-
#n_epochs ⇒ Object
Returns the value of attribute n_epochs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FineTuneDPOMethodHyperparameters
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FineTuneDPOMethodHyperparameters
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenApiOpenAIClient::FineTuneDPOMethodHyperparameters` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenApiOpenAIClient::FineTuneDPOMethodHyperparameters`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'beta') self.beta = attributes[:'beta'] end if attributes.key?(:'batch_size') self.batch_size = attributes[:'batch_size'] end if attributes.key?(:'learning_rate_multiplier') self.learning_rate_multiplier = attributes[:'learning_rate_multiplier'] end if attributes.key?(:'n_epochs') self.n_epochs = attributes[:'n_epochs'] end end |
Instance Attribute Details
#batch_size ⇒ Object
Returns the value of attribute batch_size.
21 22 23 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 21 def batch_size @batch_size end |
#beta ⇒ Object
Returns the value of attribute beta.
19 20 21 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 19 def beta @beta end |
#learning_rate_multiplier ⇒ Object
Returns the value of attribute learning_rate_multiplier.
23 24 25 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 23 def learning_rate_multiplier @learning_rate_multiplier end |
#n_epochs ⇒ Object
Returns the value of attribute n_epochs.
25 26 27 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 25 def n_epochs @n_epochs end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 28 def self.attribute_map { :'beta' => :'beta', :'batch_size' => :'batch_size', :'learning_rate_multiplier' => :'learning_rate_multiplier', :'n_epochs' => :'n_epochs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 137 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
58 59 60 61 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 58 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 48 def self.openapi_types { :'beta' => :'FineTuneDPOMethodHyperparametersBeta', :'batch_size' => :'FineTuneDPOMethodHyperparametersBatchSize', :'learning_rate_multiplier' => :'FineTuneDPOMethodHyperparametersLearningRateMultiplier', :'n_epochs' => :'FineTuneDPOMethodHyperparametersNEpochs' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
113 114 115 116 117 118 119 120 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 113 def ==(o) return true if self.equal?(o) self.class == o.class && beta == o.beta && batch_size == o.batch_size && learning_rate_multiplier == o.learning_rate_multiplier && n_epochs == o.n_epochs end |
#eql?(o) ⇒ Boolean
124 125 126 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 124 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 130 def hash [beta, batch_size, learning_rate_multiplier, n_epochs].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
98 99 100 101 102 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 98 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 159 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 |
# File 'lib/openapi_openai/models/fine_tune_dpo_method_hyperparameters.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |