Class: OpenApiOpenAIClient::InvitesApi
- Inherits:
-
Object
- Object
- OpenApiOpenAIClient::InvitesApi
- Defined in:
- lib/openapi_openai/api/invites_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_invite(invite_id, opts = {}) ⇒ InviteDeleteResponse
Delete an invite.
-
#delete_invite_with_http_info(invite_id, opts = {}) ⇒ Array<(InviteDeleteResponse, Integer, Hash)>
Delete an invite.
-
#initialize(api_client = ApiClient.default) ⇒ InvitesApi
constructor
A new instance of InvitesApi.
-
#invite_user(invite_request, opts = {}) ⇒ Invite
Create an invite for a user to the organization.
-
#invite_user_with_http_info(invite_request, opts = {}) ⇒ Array<(Invite, Integer, Hash)>
Create an invite for a user to the organization.
-
#list_invites(opts = {}) ⇒ InviteListResponse
Returns a list of invites in the organization.
-
#list_invites_with_http_info(opts = {}) ⇒ Array<(InviteListResponse, Integer, Hash)>
Returns a list of invites in the organization.
-
#retrieve_invite(invite_id, opts = {}) ⇒ Invite
Retrieves an invite.
-
#retrieve_invite_with_http_info(invite_id, opts = {}) ⇒ Array<(Invite, Integer, Hash)>
Retrieves an invite.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ InvitesApi
Returns a new instance of InvitesApi.
19 20 21 |
# File 'lib/openapi_openai/api/invites_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/openapi_openai/api/invites_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_invite(invite_id, opts = {}) ⇒ InviteDeleteResponse
Delete an invite. If the invite has already been accepted, it cannot be deleted.
26 27 28 29 |
# File 'lib/openapi_openai/api/invites_api.rb', line 26 def delete_invite(invite_id, opts = {}) data, _status_code, _headers = delete_invite_with_http_info(invite_id, opts) data end |
#delete_invite_with_http_info(invite_id, opts = {}) ⇒ Array<(InviteDeleteResponse, Integer, Hash)>
Delete an invite. If the invite has already been accepted, it cannot be deleted.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/openapi_openai/api/invites_api.rb', line 35 def delete_invite_with_http_info(invite_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitesApi.delete_invite ...' end # verify the required parameter 'invite_id' is set if @api_client.config.client_side_validation && invite_id.nil? fail ArgumentError, "Missing the required parameter 'invite_id' when calling InvitesApi.delete_invite" end # resource path local_var_path = '/organization/invites/{invite_id}'.sub('{' + 'invite_id' + '}', CGI.escape(invite_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InviteDeleteResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"InvitesApi.delete_invite", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitesApi#delete_invite\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#invite_user(invite_request, opts = {}) ⇒ Invite
Create an invite for a user to the organization. The invite must be accepted by the user before they have access to the organization.
87 88 89 90 |
# File 'lib/openapi_openai/api/invites_api.rb', line 87 def invite_user(invite_request, opts = {}) data, _status_code, _headers = invite_user_with_http_info(invite_request, opts) data end |
#invite_user_with_http_info(invite_request, opts = {}) ⇒ Array<(Invite, Integer, Hash)>
Create an invite for a user to the organization. The invite must be accepted by the user before they have access to the organization.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/openapi_openai/api/invites_api.rb', line 96 def invite_user_with_http_info(invite_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitesApi.invite_user ...' end # verify the required parameter 'invite_request' is set if @api_client.config.client_side_validation && invite_request.nil? fail ArgumentError, "Missing the required parameter 'invite_request' when calling InvitesApi.invite_user" end # resource path local_var_path = '/organization/invites' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(invite_request) # return_type return_type = opts[:debug_return_type] || 'Invite' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"InvitesApi.invite_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitesApi#invite_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_invites(opts = {}) ⇒ InviteListResponse
Returns a list of invites in the organization.
154 155 156 157 |
# File 'lib/openapi_openai/api/invites_api.rb', line 154 def list_invites(opts = {}) data, _status_code, _headers = list_invites_with_http_info(opts) data end |
#list_invites_with_http_info(opts = {}) ⇒ Array<(InviteListResponse, Integer, Hash)>
Returns a list of invites in the organization.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/openapi_openai/api/invites_api.rb', line 164 def list_invites_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitesApi.list_invites ...' end # resource path local_var_path = '/organization/invites' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InviteListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"InvitesApi.list_invites", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitesApi#list_invites\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#retrieve_invite(invite_id, opts = {}) ⇒ Invite
Retrieves an invite.
214 215 216 217 |
# File 'lib/openapi_openai/api/invites_api.rb', line 214 def retrieve_invite(invite_id, opts = {}) data, _status_code, _headers = retrieve_invite_with_http_info(invite_id, opts) data end |
#retrieve_invite_with_http_info(invite_id, opts = {}) ⇒ Array<(Invite, Integer, Hash)>
Retrieves an invite.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/openapi_openai/api/invites_api.rb', line 223 def retrieve_invite_with_http_info(invite_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitesApi.retrieve_invite ...' end # verify the required parameter 'invite_id' is set if @api_client.config.client_side_validation && invite_id.nil? fail ArgumentError, "Missing the required parameter 'invite_id' when calling InvitesApi.retrieve_invite" end # resource path local_var_path = '/organization/invites/{invite_id}'.sub('{' + 'invite_id' + '}', CGI.escape(invite_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Invite' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"InvitesApi.retrieve_invite", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitesApi#retrieve_invite\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |