Class: OpenApiOpenAIClient::ModelsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_openai/api/models_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ModelsApi



19
20
21
# File 'lib/openapi_openai/api/models_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/openapi_openai/api/models_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_model(model, opts = {}) ⇒ DeleteModelResponse

Delete a fine-tuned model. You must have the Owner role in your organization to delete a model.



26
27
28
29
# File 'lib/openapi_openai/api/models_api.rb', line 26

def delete_model(model, opts = {})
  data, _status_code, _headers = delete_model_with_http_info(model, opts)
  data
end

#delete_model_with_http_info(model, opts = {}) ⇒ Array<(DeleteModelResponse, Integer, Hash)>

Delete a fine-tuned model. You must have the Owner role in your organization to delete a model.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/openapi_openai/api/models_api.rb', line 35

def delete_model_with_http_info(model, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ModelsApi.delete_model ...'
  end
  # verify the required parameter 'model' is set
  if @api_client.config.client_side_validation && model.nil?
    fail ArgumentError, "Missing the required parameter 'model' when calling ModelsApi.delete_model"
  end
  # resource path
  local_var_path = '/models/{model}'.sub('{model}', CGI.escape(model.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteModelResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"ModelsApi.delete_model",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ModelsApi#delete_model\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_models(opts = {}) ⇒ ListModelsResponse

Lists the currently available models, and provides basic information about each one such as the owner and availability.



86
87
88
89
# File 'lib/openapi_openai/api/models_api.rb', line 86

def list_models(opts = {})
  data, _status_code, _headers = list_models_with_http_info(opts)
  data
end

#list_models_with_http_info(opts = {}) ⇒ Array<(ListModelsResponse, Integer, Hash)>

Lists the currently available models, and provides basic information about each one such as the owner and availability.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/openapi_openai/api/models_api.rb', line 94

def list_models_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ModelsApi.list_models ...'
  end
  # resource path
  local_var_path = '/models'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListModelsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"ModelsApi.list_models",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ModelsApi#list_models\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#retrieve_model(model, opts = {}) ⇒ Model

Retrieves a model instance, providing basic information about the model such as the owner and permissioning.



142
143
144
145
# File 'lib/openapi_openai/api/models_api.rb', line 142

def retrieve_model(model, opts = {})
  data, _status_code, _headers = retrieve_model_with_http_info(model, opts)
  data
end

#retrieve_model_with_http_info(model, opts = {}) ⇒ Array<(Model, Integer, Hash)>

Retrieves a model instance, providing basic information about the model such as the owner and permissioning.



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/openapi_openai/api/models_api.rb', line 151

def retrieve_model_with_http_info(model, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ModelsApi.retrieve_model ...'
  end
  # verify the required parameter 'model' is set
  if @api_client.config.client_side_validation && model.nil?
    fail ArgumentError, "Missing the required parameter 'model' when calling ModelsApi.retrieve_model"
  end
  # resource path
  local_var_path = '/models/{model}'.sub('{model}', CGI.escape(model.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Model'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"ModelsApi.retrieve_model",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ModelsApi#retrieve_model\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end