Class: OpenApiOpenAIClient::RealtimeApi
- Inherits:
-
Object
- Object
- OpenApiOpenAIClient::RealtimeApi
- Defined in:
- lib/openapi_openai/api/realtime_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_realtime_session(realtime_session_create_request, opts = {}) ⇒ RealtimeSessionCreateResponse
Create an ephemeral API token for use in client-side applications with the Realtime API.
-
#create_realtime_session_with_http_info(realtime_session_create_request, opts = {}) ⇒ Array<(RealtimeSessionCreateResponse, Integer, Hash)>
Create an ephemeral API token for use in client-side applications with the Realtime API.
-
#initialize(api_client = ApiClient.default) ⇒ RealtimeApi
constructor
A new instance of RealtimeApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RealtimeApi
Returns a new instance of RealtimeApi.
19 20 21 |
# File 'lib/openapi_openai/api/realtime_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/openapi_openai/api/realtime_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_realtime_session(realtime_session_create_request, opts = {}) ⇒ RealtimeSessionCreateResponse
Create an ephemeral API token for use in client-side applications with the Realtime API. Can be configured with the same session parameters as the session.update client event. It responds with a session object, plus a client_secret key which contains a usable ephemeral API token that can be used to authenticate browser clients for the Realtime API.
26 27 28 29 |
# File 'lib/openapi_openai/api/realtime_api.rb', line 26 def create_realtime_session(realtime_session_create_request, opts = {}) data, _status_code, _headers = create_realtime_session_with_http_info(realtime_session_create_request, opts) data end |
#create_realtime_session_with_http_info(realtime_session_create_request, opts = {}) ⇒ Array<(RealtimeSessionCreateResponse, Integer, Hash)>
Create an ephemeral API token for use in client-side applications with the Realtime API. Can be configured with the same session parameters as the `session.update` client event. It responds with a session object, plus a `client_secret` key which contains a usable ephemeral API token that can be used to authenticate browser clients for the Realtime API.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/openapi_openai/api/realtime_api.rb', line 35 def create_realtime_session_with_http_info(realtime_session_create_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RealtimeApi.create_realtime_session ...' end # verify the required parameter 'realtime_session_create_request' is set if @api_client.config.client_side_validation && realtime_session_create_request.nil? fail ArgumentError, "Missing the required parameter 'realtime_session_create_request' when calling RealtimeApi.create_realtime_session" end # resource path local_var_path = '/realtime/sessions' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(realtime_session_create_request) # return_type return_type = opts[:debug_return_type] || 'RealtimeSessionCreateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"RealtimeApi.create_realtime_session", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RealtimeApi#create_realtime_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |