Class: OpenApiOpenAIClient::RealtimeResponseUsageInputTokenDetails

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/openapi_openai/models/realtime_response_usage_input_token_details.rb

Overview

Details about the input tokens used in the Response.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RealtimeResponseUsageInputTokenDetails

Initializes the object



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenApiOpenAIClient::RealtimeResponseUsageInputTokenDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenApiOpenAIClient::RealtimeResponseUsageInputTokenDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cached_tokens')
    self.cached_tokens = attributes[:'cached_tokens']
  end

  if attributes.key?(:'text_tokens')
    self.text_tokens = attributes[:'text_tokens']
  end

  if attributes.key?(:'audio_tokens')
    self.audio_tokens = attributes[:'audio_tokens']
  end
end

Instance Attribute Details

#audio_tokensObject

The number of audio tokens used in the Response.



26
27
28
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 26

def audio_tokens
  @audio_tokens
end

#cached_tokensObject

The number of cached tokens used in the Response.



20
21
22
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 20

def cached_tokens
  @cached_tokens
end

#text_tokensObject

The number of text tokens used in the Response.



23
24
25
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 23

def text_tokens
  @text_tokens
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 29

def self.attribute_map
  {
    :'cached_tokens' => :'cached_tokens',
    :'text_tokens' => :'text_tokens',
    :'audio_tokens' => :'audio_tokens'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 131

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 48

def self.openapi_types
  {
    :'cached_tokens' => :'Integer',
    :'text_tokens' => :'Integer',
    :'audio_tokens' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



108
109
110
111
112
113
114
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 108

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cached_tokens == o.cached_tokens &&
      text_tokens == o.text_tokens &&
      audio_tokens == o.audio_tokens
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


118
119
120
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 118

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



124
125
126
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 124

def hash
  [cached_tokens, text_tokens, audio_tokens].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



93
94
95
96
97
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 93

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 153

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



101
102
103
104
# File 'lib/openapi_openai/models/realtime_response_usage_input_token_details.rb', line 101

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end