Class: OpenApiOpenAIClient::TranscriptionSegment

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/openapi_openai/models/transcription_segment.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TranscriptionSegment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/openapi_openai/models/transcription_segment.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenApiOpenAIClient::TranscriptionSegment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenApiOpenAIClient::TranscriptionSegment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'seek')
    self.seek = attributes[:'seek']
  else
    self.seek = nil
  end

  if attributes.key?(:'start')
    self.start = attributes[:'start']
  else
    self.start = nil
  end

  if attributes.key?(:'_end')
    self._end = attributes[:'_end']
  else
    self._end = nil
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'tokens')
    if (value = attributes[:'tokens']).is_a?(Array)
      self.tokens = value
    end
  else
    self.tokens = nil
  end

  if attributes.key?(:'temperature')
    self.temperature = attributes[:'temperature']
  else
    self.temperature = nil
  end

  if attributes.key?(:'avg_logprob')
    self.avg_logprob = attributes[:'avg_logprob']
  else
    self.avg_logprob = nil
  end

  if attributes.key?(:'compression_ratio')
    self.compression_ratio = attributes[:'compression_ratio']
  else
    self.compression_ratio = nil
  end

  if attributes.key?(:'no_speech_prob')
    self.no_speech_prob = attributes[:'no_speech_prob']
  else
    self.no_speech_prob = nil
  end
end

Instance Attribute Details

#_endObject

End time of the segment in seconds.



28
29
30
# File 'lib/openapi_openai/models/transcription_segment.rb', line 28

def _end
  @_end
end

#avg_logprobObject

Average logprob of the segment. If the value is lower than -1, consider the logprobs failed.



40
41
42
# File 'lib/openapi_openai/models/transcription_segment.rb', line 40

def avg_logprob
  @avg_logprob
end

#compression_ratioObject

Compression ratio of the segment. If the value is greater than 2.4, consider the compression failed.



43
44
45
# File 'lib/openapi_openai/models/transcription_segment.rb', line 43

def compression_ratio
  @compression_ratio
end

#idObject

Unique identifier of the segment.



19
20
21
# File 'lib/openapi_openai/models/transcription_segment.rb', line 19

def id
  @id
end

#no_speech_probObject

Probability of no speech in the segment. If the value is higher than 1.0 and the avg_logprob is below -1, consider this segment silent.



46
47
48
# File 'lib/openapi_openai/models/transcription_segment.rb', line 46

def no_speech_prob
  @no_speech_prob
end

#seekObject

Seek offset of the segment.



22
23
24
# File 'lib/openapi_openai/models/transcription_segment.rb', line 22

def seek
  @seek
end

#startObject

Start time of the segment in seconds.



25
26
27
# File 'lib/openapi_openai/models/transcription_segment.rb', line 25

def start
  @start
end

#temperatureObject

Temperature parameter used for generating the segment.



37
38
39
# File 'lib/openapi_openai/models/transcription_segment.rb', line 37

def temperature
  @temperature
end

#textObject

Text content of the segment.



31
32
33
# File 'lib/openapi_openai/models/transcription_segment.rb', line 31

def text
  @text
end

#tokensObject

Array of token IDs for the text content.



34
35
36
# File 'lib/openapi_openai/models/transcription_segment.rb', line 34

def tokens
  @tokens
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/openapi_openai/models/transcription_segment.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/openapi_openai/models/transcription_segment.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/openapi_openai/models/transcription_segment.rb', line 49

def self.attribute_map
  {
    :'id' => :'id',
    :'seek' => :'seek',
    :'start' => :'start',
    :'_end' => :'end',
    :'text' => :'text',
    :'tokens' => :'tokens',
    :'temperature' => :'temperature',
    :'avg_logprob' => :'avg_logprob',
    :'compression_ratio' => :'compression_ratio',
    :'no_speech_prob' => :'no_speech_prob'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/openapi_openai/models/transcription_segment.rb', line 372

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/openapi_openai/models/transcription_segment.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/openapi_openai/models/transcription_segment.rb', line 75

def self.openapi_types
  {
    :'id' => :'Integer',
    :'seek' => :'Integer',
    :'start' => :'Float',
    :'_end' => :'Float',
    :'text' => :'String',
    :'tokens' => :'Array<Integer>',
    :'temperature' => :'Float',
    :'avg_logprob' => :'Float',
    :'compression_ratio' => :'Float',
    :'no_speech_prob' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/openapi_openai/models/transcription_segment.rb', line 342

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      seek == o.seek &&
      start == o.start &&
      _end == o._end &&
      text == o.text &&
      tokens == o.tokens &&
      temperature == o.temperature &&
      avg_logprob == o.avg_logprob &&
      compression_ratio == o.compression_ratio &&
      no_speech_prob == o.no_speech_prob
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


359
360
361
# File 'lib/openapi_openai/models/transcription_segment.rb', line 359

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



365
366
367
# File 'lib/openapi_openai/models/transcription_segment.rb', line 365

def hash
  [id, seek, start, _end, text, tokens, temperature, avg_logprob, compression_ratio, no_speech_prob].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/openapi_openai/models/transcription_segment.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @seek.nil?
    invalid_properties.push('invalid value for "seek", seek cannot be nil.')
  end

  if @start.nil?
    invalid_properties.push('invalid value for "start", start cannot be nil.')
  end

  if @_end.nil?
    invalid_properties.push('invalid value for "_end", _end cannot be nil.')
  end

  if @text.nil?
    invalid_properties.push('invalid value for "text", text cannot be nil.')
  end

  if @tokens.nil?
    invalid_properties.push('invalid value for "tokens", tokens cannot be nil.')
  end

  if @temperature.nil?
    invalid_properties.push('invalid value for "temperature", temperature cannot be nil.')
  end

  if @avg_logprob.nil?
    invalid_properties.push('invalid value for "avg_logprob", avg_logprob cannot be nil.')
  end

  if @compression_ratio.nil?
    invalid_properties.push('invalid value for "compression_ratio", compression_ratio cannot be nil.')
  end

  if @no_speech_prob.nil?
    invalid_properties.push('invalid value for "no_speech_prob", no_speech_prob cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/openapi_openai/models/transcription_segment.rb', line 394

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/openapi_openai/models/transcription_segment.rb', line 225

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @seek.nil?
  return false if @start.nil?
  return false if @_end.nil?
  return false if @text.nil?
  return false if @tokens.nil?
  return false if @temperature.nil?
  return false if @avg_logprob.nil?
  return false if @compression_ratio.nil?
  return false if @no_speech_prob.nil?
  true
end