Class: OpenApiOpenAIClient::AuditLogsApi
- Inherits:
-
Object
- Object
- OpenApiOpenAIClient::AuditLogsApi
- Defined in:
- lib/openapi_openai/api/audit_logs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ AuditLogsApi
constructor
A new instance of AuditLogsApi.
-
#list_audit_logs(opts = {}) ⇒ ListAuditLogsResponse
List user actions and configuration changes within this organization.
-
#list_audit_logs_with_http_info(opts = {}) ⇒ Array<(ListAuditLogsResponse, Integer, Hash)>
List user actions and configuration changes within this organization.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuditLogsApi
Returns a new instance of AuditLogsApi.
19 20 21 |
# File 'lib/openapi_openai/api/audit_logs_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/openapi_openai/api/audit_logs_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_audit_logs(opts = {}) ⇒ ListAuditLogsResponse
List user actions and configuration changes within this organization.
34 35 36 37 |
# File 'lib/openapi_openai/api/audit_logs_api.rb', line 34 def list_audit_logs(opts = {}) data, _status_code, _headers = list_audit_logs_with_http_info(opts) data end |
#list_audit_logs_with_http_info(opts = {}) ⇒ Array<(ListAuditLogsResponse, Integer, Hash)>
List user actions and configuration changes within this organization.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/openapi_openai/api/audit_logs_api.rb', line 51 def list_audit_logs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuditLogsApi.list_audit_logs ...' end # resource path local_var_path = '/organization/audit_logs' # query parameters query_params = opts[:query_params] || {} query_params[:'effective_at'] = opts[:'effective_at'] if !opts[:'effective_at'].nil? query_params[:'project_ids[]'] = @api_client.build_collection_param(opts[:'project_ids'], :multi) if !opts[:'project_ids'].nil? query_params[:'event_types[]'] = @api_client.build_collection_param(opts[:'event_types'], :multi) if !opts[:'event_types'].nil? query_params[:'actor_ids[]'] = @api_client.build_collection_param(opts[:'actor_ids'], :multi) if !opts[:'actor_ids'].nil? query_params[:'actor_emails[]'] = @api_client.build_collection_param(opts[:'actor_emails'], :multi) if !opts[:'actor_emails'].nil? query_params[:'resource_ids[]'] = @api_client.build_collection_param(opts[:'resource_ids'], :multi) if !opts[:'resource_ids'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListAuditLogsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"AuditLogsApi.list_audit_logs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditLogsApi#list_audit_logs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |