Class: OpenApiOpenAIClient::OpenAIFile
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenApiOpenAIClient::OpenAIFile
- Defined in:
- lib/openapi_openai/models/open_ai_file.rb
Overview
The File object represents a document that has been uploaded to OpenAI.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bytes ⇒ Object
The size of the file, in bytes.
-
#created_at ⇒ Object
The Unix timestamp (in seconds) for when the file was created.
-
#filename ⇒ Object
The name of the file.
-
#id ⇒ Object
The file identifier, which can be referenced in the API endpoints.
-
#object ⇒ Object
The object type, which is always
file. -
#purpose ⇒ Object
The intended purpose of the file.
-
#status ⇒ Object
Deprecated.
-
#status_details ⇒ Object
Deprecated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OpenAIFile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OpenAIFile
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenApiOpenAIClient::OpenAIFile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenApiOpenAIClient::OpenAIFile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'bytes') self.bytes = attributes[:'bytes'] else self.bytes = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'filename') self.filename = attributes[:'filename'] else self.filename = nil end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'purpose') self.purpose = attributes[:'purpose'] else self.purpose = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'status_details') self.status_details = attributes[:'status_details'] end end |
Instance Attribute Details
#bytes ⇒ Object
The size of the file, in bytes.
23 24 25 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 23 def bytes @bytes end |
#created_at ⇒ Object
The Unix timestamp (in seconds) for when the file was created.
26 27 28 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 26 def created_at @created_at end |
#filename ⇒ Object
The name of the file.
29 30 31 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 29 def filename @filename end |
#id ⇒ Object
The file identifier, which can be referenced in the API endpoints.
20 21 22 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 20 def id @id end |
#object ⇒ Object
The object type, which is always file.
32 33 34 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 32 def object @object end |
#purpose ⇒ Object
The intended purpose of the file. Supported values are assistants, assistants_output, batch, batch_output, fine-tune, fine-tune-results and vision.
35 36 37 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 35 def purpose @purpose end |
#status ⇒ Object
Deprecated. The current status of the file, which can be either uploaded, processed, or error.
38 39 40 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 38 def status @status end |
#status_details ⇒ Object
Deprecated. For details on why a fine-tuning training file failed validation, see the error field on fine_tuning.job.
41 42 43 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 41 def status_details @status_details end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 66 def self.attribute_map { :'id' => :'id', :'bytes' => :'bytes', :'created_at' => :'created_at', :'filename' => :'filename', :'object' => :'object', :'purpose' => :'purpose', :'status' => :'status', :'status_details' => :'status_details' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 328 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 90 def self.openapi_types { :'id' => :'String', :'bytes' => :'Integer', :'created_at' => :'Integer', :'filename' => :'String', :'object' => :'String', :'purpose' => :'String', :'status' => :'String', :'status_details' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 300 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && bytes == o.bytes && created_at == o.created_at && filename == o.filename && object == o.object && purpose == o.purpose && status == o.status && status_details == o.status_details end |
#eql?(o) ⇒ Boolean
315 316 317 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 315 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
321 322 323 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 321 def hash [id, bytes, created_at, filename, object, purpose, status, status_details].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 174 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @bytes.nil? invalid_properties.push('invalid value for "bytes", bytes cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @filename.nil? invalid_properties.push('invalid value for "filename", filename cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end if @purpose.nil? invalid_properties.push('invalid value for "purpose", purpose cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 350 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/openapi_openai/models/open_ai_file.rb', line 210 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @bytes.nil? return false if @created_at.nil? return false if @filename.nil? return false if @object.nil? object_validator = EnumAttributeValidator.new('String', ["file"]) return false unless object_validator.valid?(@object) return false if @purpose.nil? purpose_validator = EnumAttributeValidator.new('String', ["assistants", "assistants_output", "batch", "batch_output", "fine-tune", "fine-tune-results", "vision"]) return false unless purpose_validator.valid?(@purpose) return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["uploaded", "processed", "error"]) return false unless status_validator.valid?(@status) true end |